==> portal-contribuinte-3.310.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/rol/findTributos.sql <==
select tribroldebito.idrol,
tribroldebito.iddebito,
tribroldebito.entidade,
tribroldebito.exercicio,
tribroldebito.tipocadastro,
tribroldebito.cadastrogeral,
tribroldebito.guiarecolhimento as divida,
tribroldebito.subdivida,
tribroldebito.dataprimeiraparcela,
tribroldebito.datacorrecao,
tribroldebito.datacorrecaoigpm,
tribroldebito.formacorrecao,
case when coalesce(tribroldebito.reparcelado, 'N') = 'S' then 1 else 0 end as reparcelado,
case when coalesce(tribroldebito.parcelado, 'N') = 'S' then 1 else 0 end as parcelado,
tribroldebito.descontolei2004,
tribdebitoparcela.parcela,
tribdebitoparcela.datalancamento,
tribdebitoparcela.datavencimento,
tribdebitoparcela.situacaolegal,
tribdebitoparcela.situacaodebito,
tribdebitoparcelareceita.iddebitoparcelareceita,
tribdebitoparcelareceita.receita as tributo,
tribdebitoparcelareceita.valor,
tribdebitoparcelareceita.valorjuros,
tribdebitoparcelareceita.valormulta,
tribdebitoparcelareceita.valorcorrecao,
tribdebitoparcelareceita.valoratualizacao,
tribsituacaoparcela.tiposituacaoparcela
from tribroldebito tribroldebito
join tribdebito tribdebito on tribroldebito.iddebito = tribdebito.iddebito
join tribdebitoparcela tribdebitoparcela on tribdebitoparcela.entidade = tribdebito.entidade
and tribdebitoparcela.exercicio = tribdebito.exercicio
and tribdebitoparcela.tipocadastro = tribdebito.tipocadastro
and tribdebitoparcela.cadastrogeral = tribdebito.cadastrogeral
and tribdebitoparcela.guiarecolhimento = tribdebito.guiarecolhimento
and tribdebitoparcela.subdivida = tribdebito.subdivida
join tribsituacaoparcela tribsituacaoparcela on tribdebitoparcela.situacaodebito = tribsituacaoparcela.situacaoparcela
join tribtiposituacaoparcela tribtiposituacaoparcela on tribtiposituacaoparcela.tiposituacaoparcela  = tribsituacaoparcela.tiposituacaoparcela
join tribdebitoparcelareceita tribdebitoparcelareceita on tribdebitoparcelareceita.entidade = tribdebitoparcela.entidade
and tribdebitoparcelareceita.exercicio = tribdebitoparcela.exercicio
and tribdebitoparcelareceita.tipocadastro = tribdebitoparcela.tipocadastro
and tribdebitoparcelareceita.cadastrogeral = tribdebitoparcela.cadastrogeral
and tribdebitoparcelareceita.guiarecolhimento = tribdebitoparcela.guiarecolhimento
and tribdebitoparcelareceita.subdivida = tribdebitoparcela.subdivida
and tribdebitoparcelareceita.parcela = tribdebitoparcela.parcela
join tribroldebitoparcela tribroldebitoparcela on tribroldebitoparcela.idrol = tribroldebito.idrol
and tribroldebitoparcela.iddebito = tribroldebito.iddebito
and tribroldebitoparcela.parcela  = tribdebitoparcela.parcela
where tribroldebito.idrol = :idRol
and tribdebito.exercicio = :exercicio
and tribdebitoparcelareceita.valor > 0
and tribdebitoparcela.situacaolegal in (:situacaoLegal)
and ((tribtiposituacaoparcela.tipo = 'A') or (tribtiposituacaoparcela.tipo <> 'A' and tribdebitoparcela.datasituacao > :dataLimiteVencimento))
%s

==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/rol/findTributos.sql <==
select tribroldebito.idrol,
tribroldebito.iddebito,
tribroldebito.entidade,
tribroldebito.exercicio,
tribroldebito.tipocadastro,
tribroldebito.cadastrogeral,
tribroldebito.guiarecolhimento as divida,
tribroldebito.subdivida,
tribroldebito.dataprimeiraparcela,
tribroldebito.datacorrecao,
tribroldebito.datacorrecaoigpm,
tribroldebito.formacorrecao,
case when coalesce(tribroldebito.reparcelado, 'N') = 'S' then 1 else 0 end as reparcelado,
case when coalesce(tribroldebito.parcelado, 'N') = 'S' then 1 else 0 end as parcelado,
tribroldebito.descontolei2004,
tribdebitoparcela.parcela,
tribdebitoparcela.datalancamento,
tribdebitoparcela.datavencimento,
tribdebitoparcela.situacaolegal,
tribdebitoparcela.situacaodebito,
tribdebitoparcelareceita.iddebitoparcelareceita,
tribdebitoparcelareceita.receita as tributo,
tribdebitoparcelareceita.valor as valorprincipal,
tribdebitoparcelareceita.valorjuros,
tribdebitoparcelareceita.valormulta,
tribdebitoparcelareceita.valorcorrecao,
tribdebitoparcelareceita.valoratualizacao,
tribsituacaoparcela.tiposituacaoparcela
from tribroldebito tribroldebito
join tribdebito tribdebito on tribroldebito.iddebito = tribdebito.iddebito
join tribdebitoparcela tribdebitoparcela on tribdebitoparcela.entidade = tribdebito.entidade
and tribdebitoparcela.exercicio = tribdebito.exercicio
and tribdebitoparcela.tipocadastro = tribdebito.tipocadastro
and tribdebitoparcela.cadastrogeral = tribdebito.cadastrogeral
and tribdebitoparcela.guiarecolhimento = tribdebito.guiarecolhimento
and tribdebitoparcela.subdivida = tribdebito.subdivida
join tribsituacaoparcela tribsituacaoparcela on tribdebitoparcela.situacaodebito = tribsituacaoparcela.situacaoparcela
join tribtiposituacaoparcela tribtiposituacaoparcela on tribtiposituacaoparcela.tiposituacaoparcela  = tribsituacaoparcela.tiposituacaoparcela
join tribdebitoparcelareceita tribdebitoparcelareceita on tribdebitoparcelareceita.entidade = tribdebitoparcela.entidade
and tribdebitoparcelareceita.exercicio = tribdebitoparcela.exercicio
and tribdebitoparcelareceita.tipocadastro = tribdebitoparcela.tipocadastro
and tribdebitoparcelareceita.cadastrogeral = tribdebitoparcela.cadastrogeral
and tribdebitoparcelareceita.guiarecolhimento = tribdebitoparcela.guiarecolhimento
and tribdebitoparcelareceita.subdivida = tribdebitoparcela.subdivida
and tribdebitoparcelareceita.parcela = tribdebitoparcela.parcela
join tribroldebitoparcela tribroldebitoparcela on tribroldebitoparcela.idrol = tribroldebito.idrol
and tribroldebitoparcela.iddebito = tribroldebito.iddebito
and tribroldebitoparcela.parcela  = tribdebitoparcela.parcela
where tribroldebito.idrol = :idRol
and tribdebito.exercicio = :exercicio
and tribdebitoparcelareceita.valor > 0
and tribdebitoparcela.situacaolegal in (:situacaoLegal)
and ((tribtiposituacaoparcela.tipo = 'A') or (tribtiposituacaoparcela.tipo <> 'A' and tribdebitoparcela.datasituacao > :dataLimiteVencimento))
%s
